#
# Copyright (c) 2010 Nokia Corporation and/or its subsidiary(-ies).
# All rights reserved.
# This component and the accompanying materials are made available
# under the terms of "Eclipse Public License v1.0"
# which accompanies this distribution, and is available
# at the URL "http://www.eclipse.org/legal/epl-v10.html".
#
# Initial Contributors:
# Nokia Corporation - initial contribution.
#
# Contributors:
#
# Description:
# Rom patch processor
#

import os
from Blocks.Packaging.PackageWriter import Dependency
from Blocks.Packaging.Logging import Logging

class RomPatchDependencyProcessor(object):
    '''
    Adds weak dependency from binary to trace package if .iby file is present
    and contains a line starting with "patchdata".

    The matching buildData must be present.
    @todo: make file match a configurable expression
    '''
    def __init__(self, *args):
        self.logger = Logging.getLogger("pfw.processors.rompatch")

    def __call__(self, component, buildData, globalFileMap):
        if component.getName() != buildData.getComponentName():
            raise ValueError("Bad dependency info for '%s'. BuildData is for another component '%s'." %
                (component.getName(), buildData.componentName))

        binPackage = component.getBinaryPackage()
        tracePackage = component.getTracePackage()
        if not (binPackage and tracePackage):
            self.logger.debug("Could not find binary and trace packages for '%s'", buildData.componentName)
            return False

        for d in component.getFiles():
            if d.getPath().lower().endswith(".iby") and os.path.normpath(d.getPath()).lower().startswith(os.path.normpath("epoc32/rom/")):
                if os.path.isfile(os.path.join(buildData.getTargetRoot(), d.getPath())):
                    for line in file(os.path.join(buildData.getTargetRoot(), d.getPath())):
                        if line.lower().startswith("patchdata"):
                            if binPackage.addDependency(Dependency(tracePackage.getName(), type="weak")):
                                self.logger.debug("%s now depends on %s", binPackage.getName(), tracePackage.getName())
                            return True
                else:
                    self.logger.info("'%s' was not found", file)